summaryrefslogtreecommitdiffstats
path: root/cervisia/diffdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'cervisia/diffdlg.cpp')
-rw-r--r--cervisia/diffdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/cervisia/diffdlg.cpp b/cervisia/diffdlg.cpp
index 1de5e48f..8d7ed8c8 100644
--- a/cervisia/diffdlg.cpp
+++ b/cervisia/diffdlg.cpp
@@ -41,8 +41,8 @@
#include "diffview.h"
-DiffDialog::DiffDialog(KConfig& cfg, TQWidget *tqparent, const char *name, bool modal)
- : KDialogBase(tqparent, name, modal, TQString(),
+DiffDialog::DiffDialog(KConfig& cfg, TQWidget *parent, const char *name, bool modal)
+ : KDialogBase(parent, name, modal, TQString(),
Close | Help | User1, Close, true, KStdGuiItem::saveAs())
, partConfig(cfg)
{
@@ -236,7 +236,7 @@ bool DiffDialog::parseCvsDiff(CvsService_stub* service, const TQString& fileName
// front end, it is executed from here. Of course, in that
// case this dialog wouldn't have to be created in the first
// place, but this design at least makes the handling trans-
// tqparent for the calling routines
TQString extdiff = partConfig.readPathEntry("ExternalDiff");
if (!extdiff.isEmpty())
@@ -236,7 +236,7 @@ bool DiffDialog::parseCvsDiff(CvsService_stub* service, const TQString& fileName
// case this dialog wouldn't have to be created in the first
// place, but this design at least makes the handling trans-
- // tqparent for the calling routines
+ // parent for the calling routines
TQString extdiff = partConfig.readPathEntry("ExternalDiff");
if (!extdiff.isEmpty())